<?php
/**
 * Add Featured Slider Options in Customizer
 *
 * @package Catch Themes
 * @subpackage Helena Pro
 * @since Helena Pro 1.0
 */

//Featured Slider
$wp_customize->add_section( 'helena_featured_slider', array(
	'priority'		=> 400,
	'title'			=> esc_html__( 'Featured Slider', 'helena-pro' ),
) );

$wp_customize->add_setting( 'featured_slider_option', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_option'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'featured_slider_option', array(
	'choices'  => helena_featured_section_enable_options(),
	'label'    => esc_html__( 'Enable Slider on', 'helena-pro' ),
	'section'  => 'helena_featured_slider',
	'settings' => 'featured_slider_option',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'featured_slider_transition_effect', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_transition_effect'],
	'sanitize_callback'	=> 'helena_sanitize_select',
) );

$wp_customize->add_control( 'featured_slider_transition_effect' , array(
	'active_callback' => 'helena_is_slider_active',
	'choices'         => helena_featured_slider_transition_effects(),
	'label'           => esc_html__( 'Transition Effect', 'helena-pro' ),
	'section'         => 'helena_featured_slider',
	'settings'        => 'featured_slider_transition_effect',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'featured_slider_transition_delay', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_transition_delay'],
	'sanitize_callback'	=> 'helena_sanitize_number_range',
) );

$wp_customize->add_control( 'featured_slider_transition_delay' , array(
	'active_callback' => 'helena_is_slider_active',
	'description'     => esc_html__( 'seconds(s)', 'helena-pro' ),
	'input_attrs'     => array(
		'style' => 'width: 100px;'
		),
	'label'           => esc_html__( 'Transition Delay', 'helena-pro' ),
	'section'         => 'helena_featured_slider',
	'settings'        => 'featured_slider_transition_delay',
) );

$wp_customize->add_setting( 'featured_slider_transition_length', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_transition_length'],
	'sanitize_callback'	=> 'helena_sanitize_number_range',
) );

$wp_customize->add_control( 'featured_slider_transition_length' , array(
		'active_callback' => 'helena_is_slider_active',
		'description'     => esc_html__( 'seconds(s)', 'helena-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 100px;'
		),
		'label'           => esc_html__( 'Transition Length', 'helena-pro' ),
		'section'         => 'helena_featured_slider',
		'settings'        => 'featured_slider_transition_length',
	)
);

$wp_customize->add_setting( 'featured_slider_image_loader', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['featured_slider_image_loader'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'featured_slider_image_loader', array(
	'active_callback' => 'helena_is_slider_active',
	'description'     => esc_html__( 'True: Fixes the height overlap issue. Slideshow will start as soon as two slider are available. Slide may display in random, as image is fetch. Wait: Fixes the height overlap issue. Slideshow will start only after all images are available.', 'helena-pro' ),
	'choices'         => helena_featured_slider_image_loader(),
	'label'           => esc_html__( 'Image Loader', 'helena-pro' ),
	'section'         => 'helena_featured_slider',
	'settings'        => 'featured_slider_image_loader',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'featured_slider_type', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_type'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'featured_slider_type', array(
	'active_callback' => 'helena_is_slider_active',
	'choices'         => helena_featured_slider_types(),
	'label'           => esc_html__( 'Select Slider Type', 'helena-pro' ),
	'section'         => 'helena_featured_slider',
	'settings'        => 'featured_slider_type',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'featured_slider_number', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_number'],
	'sanitize_callback'	=> 'helena_sanitize_number_range',
) );

$wp_customize->add_control( 'featured_slider_number' , array(
	'active_callback' => 'helena_is_demo_slider_inactive',
	'description'     => esc_html__( 'Save and refresh the page if No. of Slides is changed (Max no of slides is 20)', 'helena-pro' ),
	'input_attrs'     => array(
	'style'           => 'width: 45px;',
		'min'  => 0,
		'max'  => 20,
		'step' => 1,
	),
	'label'           => esc_html__( 'No of Slides', 'helena-pro' ),
	'section'         => 'helena_featured_slider',
	'settings'        => 'featured_slider_number',
	'type'            => 'number',
	)
);

$wp_customize->add_setting( 'exclude_slider_post', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['exclude_slider_post'],
	'sanitize_callback'	=> 'helena_sanitize_checkbox',
) );

$wp_customize->add_control(  'exclude_slider_post', array(
	'active_callback' => 'helena_is_post_slider_active',
	'label'           => esc_html__( 'Check to exclude Slider post from Homepage posts', 'helena-pro' ),
	'section'         => 'helena_featured_slider',
	'settings'        => 'exclude_slider_post',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'featured_slider_select_category', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_category_list',
) );

$wp_customize->add_control( new helena_customize_dropdown_categories_control( $wp_customize, 'helena_featured_slider_select_category', array(
	'active_callback' => 'helena_is_category_slider_active',
	'label'           => esc_html__( 'Select Categories', 'helena-pro' ),
	'name'            => 'featured_slider_select_category',
	'section'         => 'helena_featured_slider',
	'settings'        => 'featured_slider_select_category',
	'type'            => 'dropdown-categories',
) ) );

//loop for featured post sliders
$number = apply_filters( 'helena_get_option', 'featured_slider_number' );
for ( $i=1; $i <= $number ; $i++ ) {
	$wp_customize->add_setting( 'featured_slider_post_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_page',
	) );

	$wp_customize->add_control( 'featured_slider_post_'. $i, array(
		'active_callback' => 'helena_is_post_slider_active',
		'input_attrs'     => array(
			'style' => 'width: 80px;'
		),
		'label'           => esc_html__( 'Featured Post', 'helena-pro' ) . ' # ' . $i ,
		'section'         => 'helena_featured_slider',
		'settings'        => 'featured_slider_post_'. $i,
		'type'            => 'text',
		)
	);

	$wp_customize->add_setting( 'featured_slider_page_'. $i, array(
		'capability'        => 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_page',
	) );

	$wp_customize->add_control( 'featured_slider_page_'. $i, array(
		'active_callback' => 'helena_is_page_slider_active',
		'label'           => esc_html__( 'Featured Page', 'helena-pro' ) . ' # ' . $i ,
		'section'         => 'helena_featured_slider',
		'settings'        => 'featured_slider_page_'. $i,
		'type'            => 'dropdown-pages',
	) );

	$wp_customize->add_setting( 'featured_slider_note_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new helena_note_control( $wp_customize, 'featured_slider_note_'. $i, array(
		'active_callback' => 'helena_is_image_slider_active',
		'label'           => esc_html__( 'Featured Slide #', 'helena-pro' ) . $i,
		'section'         => 'helena_featured_slider',
		'settings'        => 'featured_slider_note_'. $i,
		'type'            => 'description',
	) ) );

	$wp_customize->add_setting( 'featured_slider_image_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'featured_slider_image_'. $i , array(
		'active_callback' => 'helena_is_image_slider_active',
		'label'           => esc_html__( 'Image', 'helena-pro' ),
		'section'         => 'helena_featured_slider',
		'settings'        => 'featured_slider_image_'. $i,
	) ) );

	$wp_customize->add_setting( 'featured_link_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'featured_link_'. $i, array(
		'active_callback' => 'helena_is_image_slider_active',
		'label'           => esc_html__( 'Link', 'helena-pro' ),
		'section'         => 'helena_featured_slider',
		'settings'        => 'featured_link_'. $i,
	) );

	$wp_customize->add_setting( 'featured_target_'. $i, array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'featured_target_'. $i, array(
		'active_callback' => 'helena_is_image_slider_active',
		'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'helena-pro' ),
		'section'         => 'helena_featured_slider',
		'settings'        => 'featured_target_'. $i,
		'type'            => 'checkbox',
    ) );

    $wp_customize->add_setting( 'featured_title_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'featured_title_'. $i, array(
		'active_callback' => 'helena_is_image_slider_active',
		'label'           => esc_html__( 'Title', 'helena-pro' ),
		'section'         => 'helena_featured_slider',
		'settings'        => 'featured_title_'. $i,
		'type'            => 'text',
    ) );

    $wp_customize->add_setting( 'featured_content_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'featured_content_'. $i, array(
		'active_callback' => 'helena_is_image_slider_active',
		'label'           => esc_html__( 'Content', 'helena-pro' ),
		'section'         => 'helena_featured_slider',
		'settings'        => 'featured_content_'. $i,
		'type'            => 'textarea',
    ) );
}
// Featured Slider End