<?php
/**
 * Add Hero Content Settings in Customizer
 *
 * @package Catch Themes
 * @subpackage Helena Pro
 * @since Helena Pro 1.0
 */

$wp_customize->add_section( 'helena_hero_content', array(
	'priority' => 500,
	'title'    => esc_html__( 'Hero Content', 'helena-pro' ),
) );

$wp_customize->add_setting( 'hero_content_option', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['hero_content_option'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'hero_content_option', array(
	'choices'  => helena_featured_section_enable_options(),
	'label'    => esc_html__( 'Enable Hero Content on', 'helena-pro' ),
	'section'  => 'helena_hero_content',
	'settings' => 'hero_content_option',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'hero_content_type', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['hero_content_type'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'hero_content_type', array(
	'active_callback' => 'helena_is_hero_content_active',
	'choices'         => helena_hero_content_types(),
	'label'           => esc_html__( 'Select Content Type', 'helena-pro' ),
	'section'         => 'helena_hero_content',
	'settings'        => 'hero_content_type',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'hero_content_number', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['hero_content_number'],
	'sanitize_callback' => 'helena_sanitize_number_range',
) );

$wp_customize->add_control( 'hero_content_number' , array(
		'active_callback' => 'helena_is_demo_hero_content_inactive',
		'description'     => esc_html__( 'Save and refresh the page if No. of Hero Content is changed (Max no of Hero Content is 20)', 'helena-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 45px;',
			'min'   => 0,
			'max'   => 20,
			'step'  => 1,
		),
		'label'           => esc_html__( 'No of Hero Content', 'helena-pro' ),
		'section'         => 'helena_hero_content',
		'settings'        => 'hero_content_number',
		'type'            => 'number',
		)
);

$wp_customize->add_setting( 'hero_content_enable_title', array(
		'default'           => $defaults['hero_content_enable_title'],
		'sanitize_callback' => 'helena_sanitize_checkbox',
	) );

$wp_customize->add_control(  'hero_content_enable_title', array(
	'active_callback' => 'helena_is_hero_post_page_category_content_active',
	'label'           => esc_html__( 'Check to Enable Title', 'helena-pro' ),
	'section'         => 'helena_hero_content',
	'settings'        => 'hero_content_enable_title',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'hero_content_show', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['hero_content_show'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'hero_content_show', array(
	'active_callback' => 'helena_is_hero_post_page_category_content_active',
	'choices'         => helena_featured_content_show(),
	'label'           => esc_html__( 'Display Content', 'helena-pro' ),
	'section'         => 'helena_hero_content',
	'settings'        => 'hero_content_show',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'hero_content_select_category', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_category_list',
) );

$wp_customize->add_control( new helena_customize_dropdown_categories_control( $wp_customize, 'helena_hero_content_select_category', array(
	'active_callback' => 'helena_is_hero_category_content_active',
	'label'           => esc_html__( 'Select Categories', 'helena-pro' ),
	'name'            => 'hero_content_select_category',
	'section'         => 'helena_hero_content',
	'settings'        => 'hero_content_select_category',
	'type'            => 'dropdown-categories',
) ) );

$number = apply_filters( 'helena_get_option', 'hero_content_number' );
for ( $i=1; $i <= $number ; $i++ ) {
	//post content
	$wp_customize->add_setting( 'hero_content_post_'. $i, array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'helena_sanitize_page',
		)
	);

	$wp_customize->add_control( 'hero_content_post_'. $i, array(
		'active_callback' => 'helena_is_hero_post_content_active',
		'input_attrs'     => array( 'style' => 'width: 100px;'),
		'label'           => esc_html__( 'Post', 'helena-pro' ) . ' ' . $i ,
		'section'         => 'helena_hero_content',
		'settings'        => 'hero_content_post_'. $i,
		'type'            => 'text',
	) );

	//page content
	$wp_customize->add_setting( 'hero_content_page_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_page',
	) );

	$wp_customize->add_control( 'hero_content_page_'. $i, array(
		'active_callback' => 'helena_is_hero_page_content_active',
		'label'           => esc_html__( 'Page', 'helena-pro' ) . ' ' . $i ,
		'section'         => 'helena_hero_content',
		'settings'        => 'hero_content_page_'. $i,
		'type'            => 'dropdown-pages',
	) );

	$wp_customize->add_setting( 'hero_content_note_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new helena_note_control( $wp_customize, 'hero_content_note_'. $i, array(
		'active_callback' => 'helena_is_hero_custom_content_active',
		'label'           => esc_html__( 'Hero Content #', 'helena-pro' ) .  $i,
		'section'         => 'helena_hero_content',
		'settings'        => 'hero_content_note_'. $i,
		'type'            => 'description',
	) ) );

	$wp_customize->add_setting( 'hero_content_title_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'wp_kses_post',
	) );

	$wp_customize->add_control(  'hero_content_title_'. $i, array(
		'active_callback' => 'helena_is_hero_custom_content_active',
		'label'           => esc_html__( 'Title', 'helena-pro' ),
		'section'         => 'helena_hero_content',
		'settings'        => 'hero_content_title_'. $i,
		'type'            => 'text',
    ) );

    $wp_customize->add_setting( 'hero_content_content_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'hero_content_content_'. $i, array(
		'active_callback' => 'helena_is_hero_custom_content_active',
		'label'           => esc_html__( 'Content', 'helena-pro' ),
		'section'         => 'helena_hero_content',
		'settings'        => 'hero_content_content_'. $i,
		'type'            => 'textarea',
	) );

     $wp_customize->add_setting( 'hero_content_button_text_'. $i, array(
		'capability'        => 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'hero_content_button_text_'. $i, array(
		'active_callback' => 'helena_is_hero_custom_content_active',
		'label'           => esc_html__( 'Button Text', 'helena-pro' ),
		'section'         => 'helena_hero_content',
		'settings'        => 'hero_content_button_text_'. $i,
	) );

    $wp_customize->add_setting( 'hero_content_button_link_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'hero_content_button_link_'. $i, array(
		'active_callback' => 'helena_is_hero_custom_content_active',
		'label'           => esc_html__( 'Button Link', 'helena-pro' ),
		'section'         => 'helena_hero_content',
		'settings'        => 'hero_content_button_link_'. $i,
	) );

	$wp_customize->add_setting( 'hero_content_button_target_'. $i, array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'hero_content_button_target_'. $i, array(
		'active_callback' => 'helena_is_hero_custom_content_active',
		'label'           => esc_html__( 'Check to Open Button Link in New Window/Tab', 'helena-pro' ),
		'section'         => 'helena_hero_content',
		'settings'        => 'hero_content_button_target_'. $i,
		'type'            => 'checkbox',
    ) );

    $wp_customize->add_setting( 'hero_content_image_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'hero_content_image_'. $i , array(
		'active_callback' => 'helena_is_hero_custom_content_active',
		'label'           => esc_html__( 'Image', 'helena-pro' ),
		'section'         => 'helena_hero_content',
		'settings'        => 'hero_content_image_'. $i,
	) ) );

	$wp_customize->add_setting( 'hero_content_link_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'hero_content_link_'. $i, array(
		'active_callback' => 'helena_is_hero_custom_content_active',
		'label'           => esc_html__( 'Image Link', 'helena-pro' ),
		'section'         => 'helena_hero_content',
		'settings'        => 'hero_content_link_'. $i,
	) );

	$wp_customize->add_setting( 'hero_content_target_'. $i, array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'hero_content_target_'. $i, array(
		'active_callback' => 'helena_is_hero_custom_content_active',
		'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'helena-pro' ),
		'section'         => 'helena_hero_content',
		'settings'        => 'hero_content_target_'. $i,
		'type'            => 'checkbox',
    ) );
}