<?php
/**
 * Add Portfolio Settings in Customizer
 *
 * @package Catch Themes
 * @subpackage Helena Pro
 * @since Helena Pro 1.0
 */

$wp_customize->add_section( 'helena_portfolio', array(
	'priority' => 700,
	'title'    => esc_html__( 'Portfolio', 'helena-pro' ),
) );

$wp_customize->add_setting( 'portfolio_option', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['portfolio_option'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'portfolio_option', array(
	'choices'  => helena_featured_section_enable_options(),
	'label'    => esc_html__( 'Enable Portfolio on', 'helena-pro' ),
	'section'  => 'helena_portfolio',
	'settings' => 'portfolio_option',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'portfolio_layout', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['portfolio_layout'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'portfolio_layout', array(
	'active_callback' => 'helena_is_portfolio_active',
	'choices'         => helena_featured_content_layout_options(),
	'label'           => esc_html__( 'Select Portfolio Layout', 'helena-pro' ),
	'section'         => 'helena_portfolio',
	'settings'        => 'portfolio_layout',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'portfolio_headline', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['portfolio_headline'],
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'portfolio_headline' , array(
	'active_callback' => 'helena_is_portfolio_active',
	'description'     => esc_html__( 'Leave field empty if you want to remove Headline', 'helena-pro' ),
	'label'           => esc_html__( 'Headline for Portfolio', 'helena-pro' ),
	'section'         => 'helena_portfolio',
	'settings'        => 'portfolio_headline',
	'type'            => 'text',
	)
);

$wp_customize->add_setting( 'portfolio_subheadline', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['portfolio_subheadline'],
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'portfolio_subheadline' , array(
	'active_callback' => 'helena_is_portfolio_active',
	'description'     => esc_html__( 'Leave field empty if you want to remove Sub-headline', 'helena-pro' ),
	'label'           => esc_html__( 'Sub-headline for Portfolio', 'helena-pro' ),
	'section'         => 'helena_portfolio',
	'settings'        => 'portfolio_subheadline',
	'type'            => 'text',
	)
);

$wp_customize->add_setting( 'portfolio_type', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['portfolio_type'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'portfolio_type', array(
	'active_callback' => 'helena_is_portfolio_active',
	'choices'         => helena_portfolio_types(),
	'label'           => esc_html__( 'Select Portfolio Type', 'helena-pro' ),
	'section'         => 'helena_portfolio',
	'settings'        => 'portfolio_type',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'portfolio_number', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['portfolio_number'],
	'sanitize_callback' => 'helena_sanitize_number_range',
) );

$wp_customize->add_control( 'portfolio_number' , array(
	'active_callback' => 'helena_is_demo_portfolio_inactive',
	'description'     => esc_html__( 'Save and refresh the page if No. of Portfolio is changed (Max no of Portfolio is 20)', 'helena-pro' ),
	'input_attrs'     => array(
		'style' => 'width: 45px;',
		'min'   => 0,
		'max'   => 20,
		'step'  => 1,
	),
	'label'           => esc_html__( 'No of Portfolio', 'helena-pro' ),
	'section'         => 'helena_portfolio',
	'settings'        => 'portfolio_number',
	'type'            => 'number',
	)
);

$wp_customize->add_setting( 'portfolio_select_category', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_category_list',
) );

$wp_customize->add_control( new helena_customize_dropdown_categories_control( $wp_customize, 'helena_portfolio_select_category', array(
	'active_callback' => 'helena_is_category_portfolio_active',
	'label'           => esc_html__( 'Select Categories', 'helena-pro' ),
	'name'            => 'portfolio_select_category',
	'section'         => 'helena_portfolio',
	'settings'        => 'portfolio_select_category',
	'type'            => 'dropdown-categories',
) ) );

$wp_customize->add_setting( 'portfolio_hide_category', array(
    'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_checkbox',
) );

$wp_customize->add_control(  'portfolio_hide_category', array(
	'active_callback' => 'helena_is_post_category_portfolio_inactive',
	'label'           => esc_html__( 'Check to Hide Category Meta', 'helena-pro' ),
	'section'         => 'helena_portfolio',
	'settings'        => 'portfolio_hide_category',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'portfolio_hide_tags', array(
    'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_checkbox',
) );

$wp_customize->add_control(  'portfolio_hide_tags', array(
	'active_callback' => 'helena_is_post_category_portfolio_inactive',
	'label'           => esc_html__( 'Check to Hide Tag Meta', 'helena-pro' ),
	'section'         => 'helena_portfolio',
	'settings'        => 'portfolio_hide_tags',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'portfolio_hide_date', array(
    'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_checkbox',
) );

$wp_customize->add_control(  'portfolio_hide_date', array(
	'active_callback' => 'helena_is_post_category_portfolio_inactive',
	'label'           => esc_html__( 'Check to Hide Posted On Date', 'helena-pro' ),
	'section'         => 'helena_portfolio',
	'settings'        => 'portfolio_hide_date',
	'type'            => 'checkbox',
) );

if ( is_multi_author() ) {
    $wp_customize->add_setting( 'portfolio_hide_author', array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'portfolio_hide_author', array(
		'active_callback' => 'helena_is_post_category_portfolio_inactive',
		'label'           => esc_html__( 'Check to Hide Author Meta', 'helena-pro' ),
		'section'         => 'helena_portfolio',
		'settings'        => 'portfolio_hide_author',
		'type'            => 'checkbox',
    ) );
}

$number = apply_filters( 'helena_get_option', 'portfolio_number' );
for ( $i=1; $i <= $number ; $i++ ) {

	//for featured post content
	$wp_customize->add_setting( 'portfolio_post_'. $i, array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'helena_sanitize_page',
		)
	);

	$wp_customize->add_control( 'helena_portfolio_post_'. $i, array(
			'active_callback' => 'helena_is_post_portfolio_active',
			'input_attrs'     => array(
					'style' => 'width: 100px;'
				),
			'label'           => esc_html__( 'Featured Post', 'helena-pro' ) . ' ' . $i ,
			'section'         => 'helena_portfolio',
			'settings'        => 'portfolio_post_'. $i,
			'type'            => 'text',
		)
	);

	$wp_customize->add_setting( 'portfolio_page_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_page',
	) );

	$wp_customize->add_control( 'helena_portfolio_page_'. $i, array(
		'active_callback' => 'helena_is_page_portfolio_active',
		'label'           => esc_html__( 'Featured Page', 'helena-pro' ) . ' ' . $i ,
		'section'         => 'helena_portfolio',
		'settings'        => 'portfolio_page_'. $i,
		'type'            => 'dropdown-pages',
	) );

	$wp_customize->add_setting( 'portfolio_note_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new helena_note_control( $wp_customize, 'portfolio_note_'. $i, array(
		'active_callback' => 'helena_is_image_portfolio_active',
		'label'           => esc_html__( 'Portfolio #', 'helena-pro' ) .  $i,
		'section'         => 'helena_portfolio',
		'settings'        => 'portfolio_note_'. $i,
		'type'            => 'description',
	) ) );

	$wp_customize->add_setting( 'portfolio_image_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'portfolio_image_'. $i , array(
		'active_callback' => 'helena_is_image_portfolio_active',
		'label'           => esc_html__( 'Image', 'helena-pro' ),
		'section'         => 'helena_portfolio',
		'settings'        => 'portfolio_image_'. $i,
	) ) );

	$wp_customize->add_setting( 'portfolio_link_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'portfolio_link_'. $i, array(
		'active_callback' => 'helena_is_image_portfolio_active',
		'label'           => esc_html__( 'Link', 'helena-pro' ),
		'section'         => 'helena_portfolio',
		'settings'        => 'portfolio_link_'. $i,
	) );

	$wp_customize->add_setting( 'portfolio_target_'. $i, array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'portfolio_target_'. $i, array(
		'active_callback' => 'helena_is_image_portfolio_active',
		'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'helena-pro' ),
		'section'         => 'helena_portfolio',
		'settings'        => 'portfolio_target_'. $i,
		'type'            => 'checkbox',
    ) );

    $wp_customize->add_setting( 'portfolio_title_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'portfolio_title_'. $i, array(
		'active_callback' => 'helena_is_image_portfolio_active',
		'label'           => esc_html__( 'Title', 'helena-pro' ),
		'section'         => 'helena_portfolio',
		'settings'        => 'portfolio_title_'. $i,
		'type'            => 'text',
    ) );

    $wp_customize->add_setting( 'portfolio_content_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'portfolio_content_'. $i, array(
		'active_callback' => 'helena_is_image_portfolio_active',
		'label'           => esc_html__( 'Content', 'helena-pro' ),
		'section'         => 'helena_portfolio',
		'settings'        => 'portfolio_content_'. $i,
		'type'            => 'textarea',
    ) );
}