<?php
/**
 * The template for displaying the Slider
 *
 * @package Catch Themes
 * @subpackage Helena Pro
 * @since Helena Pro 1.0
 */



if ( !function_exists( 'helena_featured_slider' ) ) :
/**
 * Add slider.
 *
 * @uses action hook helena_before_content.
 *
 * @since Helena Pro 1.0
 */
function helena_featured_slider() {
	//helena_flush_transients();
	global $wp_query;

	$enable_slider = apply_filters( 'helena_get_option', 'featured_slider_option' );

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	// Front page displays in Reading Settings
	$page_on_front = get_option('page_on_front') ;
	$page_for_posts = get_option('page_for_posts');

	if ( $enable_slider == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable_slider == 'homepage' ) ) {
		if ( ( !$output = get_transient( 'helena_featured_slider' ) ) ) {
			echo '<!-- refreshing cache -->';

			$output = '
				<section id="feature-slider">
					<div class="wrapper">
						<div class="cycle-slideshow"
						    data-cycle-log="false"
						    data-cycle-pause-on-hover="true"
						    data-cycle-swipe="true"
						    data-cycle-fx="'. esc_attr( apply_filters( 'helena_get_option', 'featured_slider_transition_effect' ) ) .'"
							data-cycle-speed="'. esc_attr( apply_filters( 'helena_get_option', 'featured_slider_transition_length' ) ) * 1000 .'"
							data-cycle-timeout="'. esc_attr( apply_filters( 'helena_get_option', 'featured_slider_transition_delay' ) ) * 1000 .'"
							data-cycle-loader="'. esc_attr( apply_filters( 'helena_get_option', 'featured_slider_image_loader' ) ) .'"
							data-cycle-slides="> article"
							>

						    <!-- prev/next links -->
						    <div class="cycle-prev"></div>
						    <div class="cycle-next"></div>

						    <!-- empty element for pager links -->
	    					<div class="cycle-pager"></div>';

	    					$select_slider 	= apply_filters( 'helena_get_option', 'featured_slider_type' );

							// Select Slider
							if ( 'demo-featured-slider' == $select_slider ) {
								$output .= helena_demo_slider();
							}
							else if ( 'featured-post-slider' == $select_slider || 'featured-page-slider' == $select_slider || 'featured-category-slider' == $select_slider ) {
								$output .= helena_post_page_category_slider();
							}
							elseif ( $select_slider == 'featured-image-slider' ) {
								$output .= helena_image_slider();
							}

			$output .= '
						</div><!-- .cycle-slideshow -->
					</div><!-- .wrapper -->
				</section><!-- #feature-slider -->';

			set_transient( 'helena_featured_slider', $output, 86940 );
		}
		echo $output;
	}
}
endif;
add_action( 'helena_after_header', 'helena_featured_slider', 20 );


if ( ! function_exists( 'helena_demo_slider' ) ) :
/**
 * This function to display featured posts slider
 *
 * @get the data value from customizer options
 *
 * @since Helena Pro 1.0
 *
 */
function helena_demo_slider() {
	return '
	<article class="post demo-image-1 hentry slides displayblock">
		<figure class="slider-image">
			<a title="Slider Image 1" href="'. esc_url( home_url( '/' ) ) .'">
				<img src="'.get_template_directory_uri().'/images/slider1-1170x658.jpg" class="wp-post-image" alt="Slider Image 1" title="Slider Image 1">
			</a>
		</figure>
		<div class="entry-container">
			<header class="entry-header">
				<h2 class="entry-title">
					<a title="Top 8 mountain getaways" href="#"><span>Top 8 mountain getaways</span></a>
				</h2>
				<div class="screen-reader-text"><span class="post-time">Posted on <time pubdate="" datetime="2014-08-16T10:56:23+00:00" class="entry-date updated">16 August, 2014</time></span><span class="post-author">By <span class="author vcard"><a rel="author" title="View all posts by Catch Themes" href="https://catchthemes.com/blog/" class="url fn n">Catch Themes</a></span></span></div>
			</header>
			<div class="entry-content">
				<p>Nepal contains part of the Himalayas, the highest mountain range in the world. Eight of the fourteen eight-thousanders are located in the country, either in whole or shared across a border with China or India.<span class="more-button"><a href="#" class="more-link">Continue reading</a></span></p>
			</div>
		</div>
	</article><!-- .slides -->

	<article class="post demo-image-2 hentry slides displaynone">
		<figure class="Slider Image 2">
			<a title="Slider Image 2" href="'. esc_url( home_url( '/' ) ) .'">
				<img src="'. get_template_directory_uri() . '/images/slider2-1170x658.jpg" class="wp-post-image" alt="Slider Image 2" title="Slider Image 2">
			</a>
		</figure>
		<div class="entry-container">
			<header class="entry-header">
				<h2 class="entry-title">
					<a title="Mountain Bar No-Bake Cookies" href="#"><span>Mountain Bar No-Bake Cookies</span></a>
				</h2>
				<div class="screen-reader-text"><span class="post-time">Posted on <time pubdate="" datetime="2014-08-16T10:56:23+00:00" class="entry-date updated">16 August, 2014</time></span><span class="post-author">By <span class="author vcard"><a rel="author" title="View all posts by Catch Themes" href="https://catchthemes.com/blog/" class="url fn n">Catch Themes</a></span></span></div>
			</header>
			<div class="entry-content">
				<p>You cannot go wrong with the primary ingredients of chocolate and peanut butter. These cookies are easy-to-make and require no baking and are gluten-free. Children seem to love these cookies and can never seem to get enough.<span class="more-button"><a href="#" class="more-link">Continue reading</a></span></p>
			</div>
		</div>
	</article><!-- .slides --> ';
}
endif; // helena_demo_slider


if ( ! function_exists( 'helena_post_page_category_slider' ) ) :
/**
 * This function to display featured post, page or category slider
 *
 * @since Helena Pro 1.0
 */
function helena_post_page_category_slider() {
	global $post;

	$no_of_post = 0; // for number of posts
	$post_list  = array();// list of valid post/page ids
	$type       = apply_filters( 'helena_get_option', 'featured_slider_type' );
	$quantity   = apply_filters( 'helena_get_option', 'featured_slider_number' );
	$more_text  = apply_filters( 'helena_get_option', 'excerpt_more_text' );
	$output     = '';

	$args = array(
		'post_type'           => 'any',
		'orderby'             => 'post__in',
		'ignore_sticky_posts' => 1 // ignore sticky posts
	);

	//Get valid number of posts
	if ( 'featured-post-slider' == $type || 'featured-page-slider' == $type  ) {
		for( $i = 1; $i <= $quantity; $i++ ){
			$post_id = '';

			if ( 'featured-post-slider' == $type ) {
				$post_id = apply_filters( 'helena_get_option', 'featured_slider_post_' . $i );
			}
			elseif ( 'featured-page-slider' == $type ) {
				$post_id = apply_filters( 'helena_get_option', 'featured_slider_page_' . $i );
			}

			if ( $post_id && '' != $post_id ) {
				$post_list = array_merge( $post_list, array( $post_id ) );

				$no_of_post++;
			}
		}

		$args['post__in'] = $post_list;
	}
	elseif ( 'featured-category-slider' == $type ) {
		$no_of_post = $quantity;

		$args['category__in'] = (array) apply_filters( 'helena_get_option', 'featured_slider_select_category' );
	}

	if ( 0 == $no_of_post ) {
		return;
	}

	$args['posts_per_page'] = $no_of_post;

	$get_featured_posts = new WP_Query( $args );

	$i=0;
	while ( $get_featured_posts->have_posts()) : $get_featured_posts->the_post(); $i++;

		$title_attribute = the_title_attribute( array( 'before' => esc_html__( 'Permalink to: ', 'helena-pro' ), 'echo' => false ) );
		$excerpt = get_the_excerpt();
		$classes[] = 'post post-'.$post->ID.' hentry slides';

		if ( $i == 1 ) {
			$classes[] =  'displayblock';
		}
		else {
			$classes[] = 'displaynone';
		}

		$output .= '
		<article class="' . esc_attr( implode( ' ', $classes ) ) . '">
			<figure class="slider-image">';
			if ( has_post_thumbnail() ) {
				$output .= '<a title="' . $title_attribute . '" href="' . esc_url( get_permalink() ) . '">
					'. get_the_post_thumbnail( $post->ID, 'helena-slider', array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class'	=> 'attached-post-image' ) ).'
				</a>';
			}
			else {
				//Default value if there is no first image
				$image = '<img class="wp-post-image" src="'.get_template_directory_uri().'/images/no-featured-image-1170x658.jpg" >';

				//Get the first image in page, returns false if there is no image
				$first_image = helena_get_first_image( $post->ID, 'helena-slider', array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class' => 'attached-post-image' ) );

				//Set value of image as first image if there is an image present in the page
				if ( '' != $first_image ) {
					$image =	$first_image;
				}

				$output .= '<a title="' . $title_attribute . '" href="' . esc_url( get_permalink() ) . '">
					'. $image .'
				</a>';
			}

			$output .= '
			</figure><!-- .slider-image -->
			<div class="entry-container">
				<header class="entry-header">
					<h2 class="entry-title">
						<a title="' . $title_attribute . '" href="' . esc_url( get_permalink() ) . '">'.the_title( '<span>','</span>', false ).'</a>
					</h2>
					<div class="screen-reader-text">'. helena_page_post_meta().'</div>
				</header>';
				if ( $excerpt !='') {
					$output .= '<div class="entry-content"><p>'. $excerpt.'</p></div>';
				}
				$output .= '
			</div><!-- .entry-container -->
		</article><!-- .slides -->';
	endwhile;

	wp_reset_query();

	return $output;
}
endif; // helena_post_page_category_slider


if ( ! function_exists( 'helena_image_slider' ) ) :
/**
 * This function to display featured posts slider
 *
 * @get the data value from theme options
 * @displays on the index
 *
 * @useage Featured Image, Title and Excerpt of Post
 *
 */
function helena_image_slider() {
	$quantity	= apply_filters( 'helena_get_option', 'featured_slider_number' );

	$image_slider = '';

	for ( $i = 1; $i <= $quantity; $i++ ) {

		$classes[] = 'image-slider image-'.$i.' hentry';

		if ( $i == 1 ) {
			$classes[] =  'displayblock';
		}
		else {
			$classes[] = 'displaynone';
		}

		$image = apply_filters( 'helena_get_option',  'featured_slider_image_'. $i  );

		//Check Image Not Empty to add in the slides
		if ( $image ) {
			//Checking Title
			$title = apply_filters( 'helena_get_option',  'featured_title_'. $i  );

			if ( !$title ) {
				$title = 'Featured Image-'.$i;
			}

			//Checking Link
			$link = apply_filters( 'helena_get_option',  'featured_link_'. $i  );
			if ( $link ) {
				$target = apply_filters( 'helena_get_option',  'featured_target_'. $i  );
				//Checking Link Target
				if ( $target ) {
					$target = '_blank';
				} else {
					$target = '_self';
				}

				//Checking image
				$image = '<a href="'. esc_url( $link ).'" title="'. esc_attr( $title ) .'" target="'.$target.'"><img alt="'. esc_attr( $title ) .'" src="'. esc_url( $image ) .'" /></a>';

				$title = '
				<header class="entry-header">
					<h2 class="entry-title">
						<a title="' . esc_attr( $title ) . '" href="' . esc_url( $link ) . '" target="' . $target . '">
							<span>' . esc_attr( $title ) . '</span>
						</a>
					</h2>
				</header>';
			}
			else {
				$link   = '';
				$target = '';
				$image  = '<img alt="'. esc_attr( $title ) .'" src="'. esc_url( $image ).'" />';
				$title  = '
				<header class="entry-header">
					<h2 class="entry-title">
						<span>' . esc_attr( $title ) . '</span>
					</h2>
				</header>';
			}

			//Checking Content
			$content = apply_filters( 'helena_get_option', 'featured_content_'. $i );
			if ( $content ) {
				$content = '
				<div class="entry-content">
					<p>' . $content . '</p>
				</div><!-- .entry-content -->';
			}

			//Content Opening and Closing
			$contentopening = '';
			$contentclosing = '';
			if ( !empty ( $title ) || !empty ( $content ) ) {
				$contentopening = '<div class="entry-container">';
				$contentclosing = '</div>';
			}
			$image_slider .= '
			<article class="' . esc_attr( implode( ' ', $classes ) ) . '">
				<figure class="slider-image">
					'. $image .'
				</figure>
				' . $contentopening . $title . $content . $contentclosing . '
			</article><!-- .slides --> ';
		}
	}
	return $image_slider;
}
endif; //helena_image_slider